package handler

import (
	"errors"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/home-user-auth/internal/logic"
	"fusenapi/home-user-auth/internal/svc"
	"fusenapi/home-user-auth/internal/types"
	"fusenapi/utils/auth"
)

func UserBasicInfoHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.Request
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    510,
				Message: "parameter error",
			})
			logx.Info(err)
			return
		}

		l := logic.NewUserBasicInfoLogic(r.Context(), svcCtx)
		userinfo := auth.CheckAuth(r)
		resp := l.UserBasicInfo(&req, &userinfo)
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
